@@ -31,7 +31,6 @@ Improvements:
 import datetime
 import sys
 
-import six
 from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
@@ -42,7 +41,7 @@ from django.db.models import (
 )
 from django.db.models.deletion import Collector
 from django.utils import timezone
-from django.utils.encoding import force_text, smart_text
+from django.utils.encoding import force_str, smart_str
 
 from django_extensions.management.utils import signalcommand
 
@@ -73,8 +72,8 @@ def orm_item_locator(orm_obj):
             if isinstance(v, datetime.datetime):
                 v = timezone.make_aware(v)
                 clean_dict[key] = StrToCodeChanger('dateutil.parser.parse("%s")' % v.isoformat())
-            elif not isinstance(v, (six.string_types, six.integer_types, float)):
-                clean_dict[key] = six.u("%s" % v)
+            elif not isinstance(v, (str, int, float)):
+                clean_dict[key] = str("%s" % v)
 
     output = """ importer.locate_object(%s, "%s", %s, "%s", %s, %s ) """ % (
         original_class, original_pk_name,
@@ -88,7 +87,7 @@ class Command(BaseCommand):
     help = 'Dumps the data as a customised python script.'
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument('appname', nargs='+')
         parser.add_argument(
             '--autofield', action='store_false', dest='skip_autofield',
@@ -153,7 +152,7 @@ def get_models(app_labels):
     return models
 
 
-class Code(object):
+class Code:
     """
     A snippet of python script.
     This keeps track of import statements and can be output to a string.
@@ -193,7 +192,7 @@ class ModelCode(Code):
     """ Produces a python script that can recreate data for a given model class. """
 
     def __init__(self, model, context=None, stdout=None, stderr=None, options=None):
-        super(ModelCode, self).__init__(indent=0, stdout=stdout, stderr=stderr)
+        super().__init__(indent=0, stdout=stdout, stderr=stderr)
         self.model = model
         if context is None:
             context = {}
@@ -206,7 +205,7 @@ class ModelCode(Code):
         Return a dictionary of import statements, with the variable being
         defined as the key.
         """
-        return {self.model.__name__: smart_text(self.model.__module__)}
+        return {self.model.__name__: smart_str(self.model.__module__)}
     imports = property(get_imports)
 
     def get_lines(self):
@@ -239,7 +238,7 @@ class InstanceCode(Code):
     def __init__(self, instance, id, context=None, stdout=None, stderr=None, options=None):
         """ We need the instance in question and an id """
 
-        super(InstanceCode, self).__init__(indent=0, stdout=stdout, stderr=stderr)
+        super().__init__(indent=0, stdout=stdout, stderr=stderr)
         self.imports = {}
 
         self.options = options
@@ -400,7 +399,7 @@ class Script(Code):
     """ Produces a complete python script that can recreate data for the given apps. """
 
     def __init__(self, models, context=None, stdout=None, stderr=None, options=None):
-        super(Script, self).__init__(stdout=stdout, stderr=stderr)
+        super().__init__(stdout=stdout, stderr=stderr)
         self.imports = {}
 
         self.models = models
@@ -496,7 +495,7 @@ class Script(Code):
     FILE_HEADER = """
 
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+
 
 # This file has been automatically generated.
 # Instead of changing it, create a file called import_helper.py
@@ -506,7 +505,7 @@ class Script(Code):
 # it will actually extend the class BasicImportHelper()
 #
 # That means you just have to overload the methods you want to
-# change, leaving the other ones inteact.
+# change, leaving the other ones intact.
 #
 # Something that you might want to do is use transactions, for example.
 #
@@ -525,7 +524,7 @@ class Script(Code):
 import os, sys
 from django.db import transaction
 
-class BasicImportHelper(object):
+class BasicImportHelper:
 
     def pre_import(self):
         pass
@@ -643,7 +642,7 @@ def flatten_blocks(lines, num_indents=-1):
         return ""
 
     # If this is a string, add the indentation and finish here
-    if isinstance(lines, six.string_types):
+    if isinstance(lines, str):
         return INDENTATION * num_indents + lines
 
     # If this is not a string, join the lines and recurse
@@ -668,7 +667,7 @@ def get_attribute_value(item, field, context, force=False, skip_autofield=True):
 
     # Post file-storage-refactor, repr() on File/ImageFields no longer returns the path
     elif isinstance(field, FileField):
-        return repr(force_text(value))
+        return repr(force_str(value))
 
     # ForeignKey fields, link directly using our stored python variable name
     elif isinstance(field, ForeignKey) and value is not None:
